@@ -100,6 +100,21 @@ class TestMeta(unittest.TestCase):
         meta = self.sess.metadata.get(DataObject, self.obj_path)   # ... check integrity of change
         self.assertEqual(sorted([AVU_Units_String(i) for i in meta]), ["","units_244"])
 
+    def test_atomic_metadata_operations_255(self):
+        my_resc = self.sess.resources.create('dummyResc','passthru')
+        avus = [iRODSMeta('a','b','c'), iRODSMeta('d','e','f')]
+        objects = [ self.sess.users.get("rods"), self.sess.user_groups.get("public"), my_resc,
+                    self.sess.collections.get(self.coll_path), self.sess.data_objects.get(self.obj_path)  ]
+        try:
+            for obj in objects:
+                self.assertEqual(len(obj.metadata.items()), 0)
+                for n,item in enumerate(avus):
+                    obj.metadata.apply_atomic_operations(AVUOperation(operation='add',avu=item))
+                    self.assertEqual(len(obj.metadata.items()), n+1)
+        finally:
+            for obj in objects: obj.metadata.remove_all()
+            my_resc.remove()
+
     def test_get_obj_meta(self):
         # get object metadata
         meta = self.sess.metadata.get(DataObject, self.obj_path)
