@@ -55,8 +55,8 @@ class TestQuery(unittest.TestCase):
     def tearDownClass(cls):
         with helpers.make_session() as sess:
             try:
-                resc = sess.resources.get(cls.register_resc)
-                resc.remove()
+                if cls.register_resc:
+                    sess.resources.get(cls.register_resc).remove()
             except Exception as e:
                 print( "Could not remove resc {!r} due to: {} ".format(cls.register_resc,e),
                  file=sys.stderr)
@@ -338,20 +338,34 @@ class TestQuery(unittest.TestCase):
         results = [r[DataObject.name] for r in q]
         self.assertTrue(len(results) == len(dummy_test))
 
+
+    def common_dir_or_vault_info(self):
+        register_opts= {}
+        dir_ = None
+        if self.register_resc:
+            dir_ = irods_shared_reg_resc_vault()
+            register_opts[ kw.RESC_NAME_KW ] = self.register_resc
+        if not(dir_) and helpers.irods_session_host_local (self.sess):
+            dir_ = tempfile.gettempdir()
+        if not dir_:
+            return ()
+        else:
+            return (dir_ , register_opts)
+
+
     @unittest.skipIf(six.PY3, 'Test is for python2 only')
     def test_query_for_data_object_with_utf8_name_python2(self):
-
-        if not helpers.irods_session_host_local (self.sess) and not( self.register_resc ):
-            self.skipTest('for non-local server - registering data objects requires a shared path')
-
+        reg_info = self.common_dir_or_vault_info()
+        if not reg_info:
+            self.skipTest('server is non-localhost and no common path exists for object registration')
+        (dir_,resc_option) = reg_info
         filename_prefix = '_prefix_ǠǡǢǣǤǥǦǧǨǩǪǫǬǭǮǯǰǱǲǳǴǵǶǷǸ'
         self.assertEqual(self.FILENAME_PREFIX.encode('utf-8'), filename_prefix)
-        dir_ = irods_shared_reg_resc_vault()
         _,test_file = tempfile.mkstemp(dir=dir_,prefix=filename_prefix)
         obj_path = os.path.join(self.coll.path, os.path.basename(test_file))
         results = None
         try:
-            self.sess.data_objects.register(test_file, obj_path, **{kw.RESC_NAME_KW: self.register_resc})
+            self.sess.data_objects.register(test_file, obj_path, **resc_option)
             results = self.sess.query(DataObject, Collection.name).filter(DataObject.path == test_file).first()
             result_logical_path = os.path.join(results[Collection.name], results[DataObject.name])
             result_physical_path = results[DataObject.path]
@@ -366,10 +380,10 @@ class TestQuery(unittest.TestCase):
 
     @unittest.skipIf(six.PY2, 'Test is for python3 only')
     def test_query_for_data_object_with_utf8_name_python3(self):
-
-        if not helpers.irods_session_host_local (self.sess) and not( self.register_resc ):
-            self.skipTest('for non-local server - registering data objects requires a shared path')
-
+        reg_info = self.common_dir_or_vault_info()
+        if not reg_info:
+            self.skipTest('server is non-localhost and no common path exists for object registration')
+        (dir_,resc_option) = reg_info
         def python34_unicode_mkstemp( prefix, dir = None, open_mode = 0o777 ):
             file_path = os.path.join ((dir or os.environ.get('TMPDIR') or '/tmp'), prefix+'-'+str(uuid.uuid1()))
             encoded_file_path = file_path.encode('utf-8')
@@ -379,7 +393,6 @@ class TestQuery(unittest.TestCase):
             u'\u01e0\u01e1\u01e2\u01e3\u01e4\u01e5\u01e6\u01e7\u01e8\u01e9\u01ea\u01eb\u01ec\u01ed\u01ee\u01ef'\
             u'\u01f0\u01f1\u01f2\u01f3\u01f4\u01f5\u01f6\u01f7\u01f8'  # make more visible/changeable in VIM
         self.assertEqual(self.FILENAME_PREFIX, filename_prefix)
-        dir_ = irods_shared_reg_resc_vault()
         (fd,encoded_test_file) = tempfile.mkstemp(dir = dir_.encode('utf-8'),prefix=filename_prefix.encode('utf-8')) \
             if sys.version_info >= (3,5) \
             else python34_unicode_mkstemp(dir = dir_, prefix = filename_prefix)
@@ -388,7 +401,7 @@ class TestQuery(unittest.TestCase):
         obj_path = os.path.join(self.coll.path, os.path.basename(test_file))
         results = None
         try:
-            self.sess.data_objects.register(test_file, obj_path, **{kw.RESC_NAME_KW: self.register_resc})
+            self.sess.data_objects.register(test_file, obj_path, **resc_option)
             results = list(self.sess.query(DataObject, Collection.name).filter(DataObject.path == test_file))
             if results:
                 results = results[0]
